@@ -15,7 +15,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
  ***************************************************************************/
 
 #ifndef GESTOR_PESQUISA_H
@@ -27,6 +27,8 @@
 #include <qstring.h>
 #include <qdatetime.h>
 #include <qregexp.h>
+#include <qmap.h>
+class QDomElement;
 
 #include <vector>
 
@@ -37,6 +39,7 @@
 
 using namespace std;
 
+typedef QMap<QString, KHTMLPart*> KHTMLPartMap;
 
 class SearchManager: public QObject
 {
@@ -53,6 +56,15 @@ public:
     SearchManager(int max_simultaneous_connections = 3, int time_out = 50,
                   QObject *parent = 0, const char *name = 0);
     ~SearchManager();
+    
+    QString toXML() const;
+    void save(QDomElement& element) const;
+
+    KHTMLPartMap const& htmlParts() const { return html_parts_; }
+
+    KHTMLPart* htmlPart(QString const& key_url) const;
+    void addHtmlPart(QString const& key_url, KHTMLPart* html_part);
+    void removeHtmlParts();
 
     void startSearch(KURL const& root);
     void startSearch(KURL const& root, SearchMode const& modo);
@@ -76,6 +88,7 @@ public:
     bool localDomain(KURL const& url, bool restrict = true) const;
     //bool isLocalRestrict(KURL const& url) const;
     SearchMode const& searchMode() const;
+    bool checkRegularExpressions() const { return check_regular_expressions_; }
     bool existUrl(KURL const& url, KURL const& url_parent) const;
     LinkStatus const* linkStatus(QString const& s_url) const;
     int checkedLinks() const;
@@ -160,6 +173,7 @@ private:
     uint number_of_level_links_;
     uint number_of_links_to_check_;
     vector< vector< vector <LinkStatus*> > > search_results_;
+    KHTMLPartMap html_parts_;
 };
 
 #include "searchmanager_impl.h"
