@@ -15,7 +15,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
  ***************************************************************************/
 
 
@@ -90,8 +90,7 @@ inline void SearchManager::setCheckRegularExpressions(bool flag)
 
 inline void SearchManager::setRegularExpression(QString const& reg_exp, bool case_sensitive)
 {
-    QRegExp aux(reg_exp, case_sensitive);
-    reg_exp_ = aux;
+    reg_exp_ = QRegExp(reg_exp, case_sensitive);
 }
 
 inline void SearchManager::setTimeOut(int time_out)
