@@ -15,11 +15,14 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
  ***************************************************************************/
 #include "tabwidgetsession.h"
 #include "sessionwidget.h"
+#include "klsconfig.h"
+#include "treeview.h"
 #include "../engine/searchmanager.h"
+#include "../actionmanager.h"
 
 #include <qtoolbutton.h>
 #include <qcursor.h>
@@ -31,18 +34,42 @@
 
 #include <kapplication.h>
 #include <kstandarddirs.h>
-#include <kurl.h>
 #include <klocale.h>
 #include <kstringhandler.h> 
+#include <kcharsets.h>
+#include <kmimetype.h>
+#include <kaction.h>
+#include <kiconloader.h>
 
 
 TabWidgetSession::TabWidgetSession(QWidget* parent, const char* name, WFlags f)
-        : QTabWidget(parent, name, f) // tabs_ is initialized with size 17
+        : KTabWidget(parent, name, f) // tabs_ is initialized with size 17
 {
-    setFocusPolicy( QTabWidget::NoFocus );
-    setMargin( 0 );
-
+    setFocusPolicy(QTabWidget::NoFocus);
+    setMargin(0);
+    setTabReorderingEnabled(true);
+    setHoverCloseButton(true);
+    setHoverCloseButtonDelayed(true);
+    
     tabs_.setAutoDelete(false);
+    
+    QToolButton* tabs_new = new QToolButton(this);
+    tabs_new->setAccel(QKeySequence("Ctrl+N"));
+    connect(tabs_new, SIGNAL(clicked()), this, SLOT(slotNewSession()));
+    tabs_new->setIconSet(SmallIconSet("tab_new_raised"));
+    tabs_new->adjustSize();
+    QToolTip::add(tabs_new, i18n("Open new tab"));
+    setCornerWidget(tabs_new, TopLeft);
+
+    tabs_close_ = new QToolButton(this);
+    tabs_close_->setAccel(QKeySequence("Ctrl+W"));
+    connect(tabs_close_, SIGNAL(clicked()), this, SLOT(closeSession()));
+    tabs_close_->setIconSet(SmallIconSet("tab_remove"));
+    tabs_close_->adjustSize();
+    QToolTip::add(tabs_close_, i18n("Close the current tab"));
+    setCornerWidget(tabs_close_, TopRight);
+
+    connect(this, SIGNAL(currentChanged(QWidget*)), this, SLOT(slotCurrentChanged(QWidget*)));
 }
 
 TabWidgetSession::~TabWidgetSession()
@@ -90,8 +117,8 @@ SessionWidget* TabWidgetSession::newSession()
 {
     // TODO: settings: number of connections, timeout
     SessionWidget* session_widget = newSessionWidget();
-    connect(session_widget, SIGNAL(signalUpdateTabLabel(const LinkStatus * )),
-            this, SLOT(updateTabLabel(const LinkStatus * )));
+    connect(session_widget, SIGNAL(signalUpdateTabLabel(const LinkStatus *, SessionWidget*)),
+            this, SLOT(updateTabLabel(const LinkStatus *, SessionWidget*)));
 
     insertTab(session_widget, i18n("Session") + i18n(QString::number(count() + 1).ascii()));
     
@@ -114,30 +141,33 @@ void TabWidgetSession::closeSession()
 {
     if(count() > 1)
         removePage(currentPage());
+
+    tabs_close_->setEnabled(count() > 1);
+    ActionManager::getInstance()->action("close_tab")->setEnabled(count() > 1);
 }
 
 SessionWidget* TabWidgetSession::newSessionWidget()
 {
-    // TODO: settings: number of connections, timeout
-    SessionWidget* session_widget = new SessionWidget( 5, 30, this, "session_widget");
+    KLSConfig* config = KLSConfig::self();
+
+    SessionWidget* session_widget = new SessionWidget(config->maxConnectionsNumber(), 
+            config->timeOut(), this, QString("session_widget-" + count()));
 
     QStringList columns;
-    /*
-    columns.push_back(i18n("Status"));
-    columns.push_back(i18n("Label"));
-    columns.push_back(i18n("URL"));
-    */
     columns.push_back(i18n("URL"));
     columns.push_back(i18n("Status"));
     columns.push_back(i18n("Label"));
     session_widget->setColumns(columns);
 
+    session_widget->tree_view->restoreLayout(config->config(), "klinkstatus");
+
     return session_widget;
 }
 
-void TabWidgetSession::updateTabLabel(LinkStatus const* linkstatus)
+void TabWidgetSession::updateTabLabel(LinkStatus const* linkstatus, SessionWidget* page)
 {
     QString label;
+    KURL url = linkstatus->absoluteUrl();
     
     if(linkstatus->hasHtmlDocTitle())
     {
@@ -146,7 +176,6 @@ void TabWidgetSession::updateTabLabel(LinkStatus const* linkstatus)
     }
     else
     {
-        KURL url = linkstatus->absoluteUrl();
         if(url.fileName(false).isEmpty())
             label = url.prettyURL();
         else
@@ -154,7 +183,9 @@ void TabWidgetSession::updateTabLabel(LinkStatus const* linkstatus)
         
         label = KStringHandler::lsqueeze(label, 30);        
     }
-    changeTab(currentPage(), label);
+    
+    changeTab(page, KCharsets::resolveEntities(label));
+    setTabIconSet(page, QIconSet(KMimeType::pixmapForURL(url)));
 }
 
 void TabWidgetSession::slotLoadSettings()
@@ -177,4 +208,65 @@ void TabWidgetSession::setUrl(KURL const& url)
     currentSession()->setUrl(url);
 }
 
+void TabWidgetSession::slotCurrentChanged(QWidget* /*page*/)
+{
+    tabs_close_->setEnabled(count() > 1);
+
+    SessionWidget* session_widget = currentSession();
+    ActionManager::getInstance()->slotUpdateSessionWidgetActions(session_widget);
+}
+
+void TabWidgetSession::slotHideSearchPanel()
+{
+    currentSession()->slotHideSearchPanel();
+}
+
+void TabWidgetSession::slotFollowLastLinkChecked()
+{
+    currentSession()->slotFollowLastLinkChecked();
+}
+
+void TabWidgetSession::slotResetSearchOptions()
+{
+    currentSession()->slotResetSearchOptions();
+}
+
+void TabWidgetSession::slotNewSession(KURL const& url)
+{
+    if(count() == 0 || !emptySessionsExist())
+    {
+        SessionWidget* sessionwidget = newSession(url);
+        ActionManager::getInstance()->initSessionWidget(sessionwidget);        
+    }
+    else
+    {
+        SessionWidget* sessionwidget = getEmptySession();
+        sessionwidget->setUrl(url);
+        showPage(sessionwidget);
+    }
+
+    ActionManager::getInstance()->action("close_tab")->setEnabled(count() > 1);
+}
+
+void TabWidgetSession::slotStartSearch()
+{
+    currentSession()->slotStartSearch();
+}
+
+void TabWidgetSession::slotPauseSearch()
+{
+    currentSession()->slotPauseSearch();
+}
+
+void TabWidgetSession::slotStopSearch()
+{
+    currentSession()->slotStopSearch();
+}
+
+void TabWidgetSession::slotExportAsHTML()
+{
+    currentSession()->slotExportAsHTML();
+}
+
+
 #include "tabwidgetsession.moc"
