@@ -411,7 +411,10 @@ void TreeViewItem::init(LinkStatus const* linkstatus)
     {
         TreeColumnViewItem item(linkstatus, i + 1);
         column_items_.push_back(item);
-        setText(item.columnIndex() - 1, KCharsets::resolveEntities(item.text(i + 1)));
+        
+        setText(item.columnIndex() - 1, KURL::decode_string(
+                KCharsets::resolveEntities(item.text(i + 1))));
+        
         setPixmap(item.columnIndex() - 1, item.pixmap(i + 1));
     }
 }
@@ -439,7 +442,7 @@ QString TreeViewItem::key(int column, bool) const
     return text(column);
 }
 
-LinkStatus const* const TreeViewItem::linkStatus() const
+LinkStatus const* TreeViewItem::linkStatus() const
 {
     return column_items_[0].linkStatus();
 }
@@ -483,7 +486,7 @@ int TreeColumnViewItem::columnIndex() const
     return column_index_;
 }
 
-LinkStatus const* const TreeColumnViewItem::linkStatus() const
+LinkStatus const* TreeColumnViewItem::linkStatus() const
 {
     Q_ASSERT(ls_);
     return ls_;
