@@ -51,12 +51,12 @@ static int dbcount  = 0;
 static int dbcustomcount = 200;
 static QStrList *wGroups;
 static QStrList *invisibleGroups;
-static bool whatsThisLoaded = FALSE;
+static bool whatsThisLoaded = false;
 #ifndef KOMMANDER
 static QPluginManager<WidgetInterface> *widgetPluginManager = 0;
 #endif
-static bool plugins_set_up = FALSE;
-static bool was_in_setup = FALSE;
+static bool plugins_set_up = false;
+static bool was_in_setup = false;
 
 #ifndef KOMMANDER
 QCleanupHandler<QPluginManager<WidgetInterface> > cleanup_manager;
@@ -64,8 +64,8 @@ QCleanupHandler<QPluginManager<WidgetInterface> > cleanup_manager;
 
 WidgetDatabaseRecord::WidgetDatabaseRecord()
 {
-    isForm = FALSE;
-    isContainer = FALSE;
+    isForm = false;
+    isContainer = false;
     icon = 0;
     nameCounter = 0;
 }
@@ -106,7 +106,7 @@ WidgetDatabase::WidgetDatabase()
 
 void WidgetDatabase::setupDataBase( int id )
 {
-  was_in_setup = TRUE;
+  was_in_setup = true;
 #ifndef UIC
   Q_UNUSED(id) if (dbcount)
     return;
@@ -127,7 +127,7 @@ void WidgetDatabase::setupDataBase( int id )
   invisibleGroups->append("Forms");
   invisibleGroups->append("Temp");
   className2Id = new QDict < int >(dbdictsize);
-  className2Id->setAutoDelete(TRUE);
+  className2Id->setAutoDelete(true);
 
   WidgetDatabaseRecord *r = 0;
 
@@ -165,7 +165,7 @@ void WidgetDatabase::setupDataBase( int id )
   r->name = "QGroupBox";
   r->group = widgetGroup("Containers");
   r->toolTip = i18n("Group Box");
-  r->isContainer = TRUE;
+  r->isContainer = true;
   append(r);
 
   r = new WidgetDatabaseRecord;
@@ -173,7 +173,7 @@ void WidgetDatabase::setupDataBase( int id )
   r->name = "QButtonGroup";
   r->group = widgetGroup("Containers");
   r->toolTip = i18n("Button Group");
-  r->isContainer = TRUE;
+  r->isContainer = true;
   append(r);
 
   r = new WidgetDatabaseRecord;
@@ -181,7 +181,7 @@ void WidgetDatabase::setupDataBase( int id )
   r->name = "QFrame";
   r->group = widgetGroup("Containers");
   r->toolTip = i18n("Frame");
-  r->isContainer = TRUE;
+  r->isContainer = true;
   append(r);
 
   r = new WidgetDatabaseRecord;
@@ -189,7 +189,7 @@ void WidgetDatabase::setupDataBase( int id )
   r->name = "QTabWidget";
   r->group = widgetGroup("Containers");
   r->toolTip = i18n("Tabwidget");
-  r->isContainer = TRUE;
+  r->isContainer = true;
   append(r);
 
   r = new WidgetDatabaseRecord;
@@ -360,61 +360,61 @@ void WidgetDatabase::setupDataBase( int id )
 
   r = new WidgetDatabaseRecord;
   r->name = "QWidget";
-  r->isForm = TRUE;
+  r->isForm = true;
   r->group = widgetGroup("Forms");
   append(r);
 
   r = new WidgetDatabaseRecord;
   r->name = "QDialog";
   r->group = widgetGroup("Forms");
-  r->isForm = TRUE;
+  r->isForm = true;
   append(r);
 
   r = new WidgetDatabaseRecord;
   r->name = "QWizard";
   r->group = widgetGroup("Forms");
-  r->isContainer = TRUE;
+  r->isContainer = true;
   append(r);
 
   r = new WidgetDatabaseRecord;
   r->name = "QDesignerWizard";
   r->group = widgetGroup("Forms");
-  r->isContainer = TRUE;
+  r->isContainer = true;
   append(r);
 
   r = new WidgetDatabaseRecord;
   r->name = "QLayoutWidget";
   r->group = widgetGroup("Temp");
   r->includeFile = "";
-  r->isContainer = TRUE;
+  r->isContainer = true;
   append(r);
 
   r = new WidgetDatabaseRecord;
   r->name = "QSplitter";
   r->group = widgetGroup("Temp");
   r->includeFile = "qsplitter.h";
-  r->isContainer = TRUE;
+  r->isContainer = true;
   append(r);
 
   r = new WidgetDatabaseRecord;
   r->iconSet = "tabwidget.xpm";
   r->name = "QDesignerTabWidget";
   r->group = widgetGroup("Temp");
-  r->isContainer = TRUE;
+  r->isContainer = true;
   append(r);
 
   r = new WidgetDatabaseRecord;
   r->iconSet = "tabwidget.xpm";
   r->name = "QDesignerWidget";
   r->group = widgetGroup("Temp");
-  r->isContainer = TRUE;
+  r->isContainer = true;
   append(r);
 
   r = new WidgetDatabaseRecord;
   r->iconSet = "tabwidget.xpm";
   r->name = "QDesignerDialog";
   r->group = widgetGroup("Temp");
-  r->isContainer = TRUE;
+  r->isContainer = true;
   append(r);
 
   r = new WidgetDatabaseRecord;
@@ -422,7 +422,7 @@ void WidgetDatabase::setupDataBase( int id )
   r->name = "QMainWindow";
   r->includeFile = "qmainwindow.h";
   r->group = widgetGroup("Temp");
-  r->isContainer = TRUE;
+  r->isContainer = true;
   append(r);
 
 #ifndef QT_NO_SQL
@@ -432,7 +432,7 @@ void WidgetDatabase::setupDataBase( int id )
   r->group = widgetGroup("Database");
   r->toolTip = "Data Browser";
   r->iconSet = "databrowser.xpm";
-  r->isContainer = TRUE;
+  r->isContainer = true;
   append(r);
 
   r = new WidgetDatabaseRecord;
@@ -441,42 +441,42 @@ void WidgetDatabase::setupDataBase( int id )
   r->group = widgetGroup("Database");
   r->toolTip = "Data View";
   r->iconSet = "dataview.xpm";
-  r->isContainer = TRUE;
+  r->isContainer = true;
   append(r);
 #endif
 
   r = new WidgetDatabaseRecord;
   r->name = "Dialog";
   r->group = widgetGroup("Forms");
-  r->isContainer = TRUE;
-  r->isForm = TRUE;
+  r->isContainer = true;
+  r->isForm = true;
   append(r);
 
   r = new WidgetDatabaseRecord;
   r->name = "Wizard";
   r->group = widgetGroup("Forms");
-  r->isContainer = TRUE;
-  r->isForm = TRUE;
+  r->isContainer = true;
+  r->isForm = true;
   append(r);
   
   r = new WidgetDatabaseRecord;
   r->name = "EditorDialog";
   r->group = widgetGroup("Temp");
-  r->isContainer = TRUE;
-  r->isForm = TRUE;
+  r->isContainer = true;
+  r->isForm = true;
   append(r);
 
   r = new WidgetDatabaseRecord;
   r->name = "EditorWizard";
   r->group = widgetGroup("Temp");
-  r->isContainer = TRUE;
-  r->isForm = TRUE;
+  r->isContainer = true;
+  r->isForm = true;
   append(r);
   
   r = new WidgetDatabaseRecord;
   r->name = "EditorTabWidget";
   r->group = widgetGroup("Temp");
-  r->isContainer = TRUE;
+  r->isContainer = true;
   append(r);
 
 
@@ -594,7 +594,7 @@ void WidgetDatabase::setupDataBase( int id )
   r->name = "ButtonGroup";
   r->group = widgetGroup("Kommander");
   r->toolTip = i18n("A widget for grouping buttons together");
-  r->isContainer = TRUE;
+  r->isContainer = true;
   append(r);
 
   r = new WidgetDatabaseRecord;
@@ -602,7 +602,7 @@ void WidgetDatabase::setupDataBase( int id )
   r->name = "GroupBox";
   r->group = widgetGroup("Kommander");
   r->toolTip = i18n("A widget for grouping other widgets together");
-  r->isContainer = TRUE;
+  r->isContainer = true;
   append(r);
 
   r = new WidgetDatabaseRecord;
@@ -610,7 +610,7 @@ void WidgetDatabase::setupDataBase( int id )
   r->name = "TabWidget";
   r->group = widgetGroup("Kommander");
   r->toolTip = i18n("A widget with tabs");
-  r->isContainer = TRUE;
+  r->isContainer = true;
   append(r);
 
   r = new WidgetDatabaseRecord;
@@ -672,7 +672,7 @@ void WidgetDatabase::setupPlugins()
   if (plugins_set_up)
     return;
   //qDebug("WidgetDatabase::setupPlugins");
-  plugins_set_up = TRUE;
+  plugins_set_up = true;
   FeatureList widgets = KommanderFactory::featureList();
   //qDebug("num features = %d", widgets.count());
   for (FeatureList::Iterator it = widgets.begin(); it != widgets.end(); ++it)
@@ -807,7 +807,7 @@ bool WidgetDatabase::isForm( int id )
     setupDataBase( id );
     WidgetDatabaseRecord *r = at( id );
     if ( !r )
-	return FALSE;
+	return false;
     return r->isForm;
 }
 
@@ -819,7 +819,7 @@ bool WidgetDatabase::isContainer( int id )
     setupDataBase( id );
     WidgetDatabaseRecord *r = at( id );
     if ( !r )
-	return FALSE;
+	return false;
     return r->isContainer || r->isForm;
 }
 
@@ -909,13 +909,13 @@ bool WidgetDatabase::isGroupEmpty( const QString &grp )
 	{
 	// FIXME
 	    if(r->group == "Kommander")
-		    return FALSE;
+		    return false;
 
 	    if(r->name[0] != 'Q')
-  	        return FALSE;
+  	        return false;
 	}
     }
-    return TRUE;
+    return true;
 }
 
 QString WidgetDatabase::widgetGroup( int i )
@@ -947,8 +947,8 @@ int WidgetDatabase::addCustomWidget( WidgetDatabaseRecord *r )
 bool WidgetDatabase::isCustomWidget( int id )
 {
     if ( id >= dbcustom && id < dbcustomcount )
-	return TRUE;
-    return FALSE;
+	return true;
+    return false;
 }
 
 bool WidgetDatabase::isWhatsThisLoaded()
@@ -971,14 +971,14 @@ void WidgetDatabase::loadWhatsThis( const QString &docPath )
 	if ( r )
 	    r->whatsThis = l[ 0 ];
     }
-    whatsThisLoaded = TRUE;
+    whatsThisLoaded = true;
 }
 
 
 // ### Qt 3.1: make these publically accessible via QWidgetDatabase API
 #ifndef KOMMANDER
 #if defined(UIC)
-bool dbnounload = FALSE;
+bool dbnounload = false;
 QStringList *dbpaths = 0;
 #endif
 
@@ -994,7 +994,7 @@ QPluginManager<WidgetInterface> *widgetManager()
 	cleanup_manager.add( &widgetPluginManager );
 #if defined(UIC)
 	if ( dbnounload )
-	    widgetPluginManager->setAutoUnload( FALSE );
+	    widgetPluginManager->setAutoUnload( false );
 	if ( dbpaths ) {
 	    QStringList::ConstIterator it = dbpaths->begin();
 	    for ( ; it != dbpaths->end(); ++it )
