@@ -48,8 +48,8 @@ QString QExtFileInfo::canonicalPath(const QString& path)
     return s;
   } else
   {
-    dir.cdUp();
-    QString s = dir.path() + "/";
+    KURL u = KURL::fromPathOrURL(path).upURL();
+    QString s = u.path(-1) + "/";
     QString s2 = path.mid(s.length());
     s2 = QExtFileInfo::canonicalPath(s) + s2;
     return s2;
