@@ -669,6 +669,8 @@ Node* SAParser::parseArea(const AreaStruct &specialArea,
   }
   m_write->addDTEP(s_dtd->name);
   s_searchForSpecialAreas = (s_dtd->specialAreas.count() > 0);
+  if (s_parentNode && s_parentNode->tag->type == Tag::Comment)
+    s_searchForSpecialAreas = false;
   s_col = s_startCol + areaStartString.length();
   s_line = s_startLine;
   s_textLine = m_write->text(s_startLine, 0, s_startLine, m_write->editIf->lineLength(s_startLine));
@@ -732,9 +734,12 @@ Node *SAParser::parsingDone()
         Node *n = m_lastParsedNode;
         if (m_useNext)
         {
+//           kdDebug(24000) << "m_lastParsedNode: " << m_lastParsedNode << " " << m_lastParsedNode->tag->tagStr() << endl;
           n->next = s_next;
           if (s_next)
+          {
             s_next->prev = n;
+          }
           n->prev = s_parentNode;
         }
         m_currentNode = n->nextSibling();
@@ -754,7 +759,7 @@ Node *SAParser::parsingDone()
 #endif
           emit rebuildStructureTree(false);
 #ifdef DEBUG_PARSER
-          kdDebug(24000) << "Calling cleanGroups from SAParser::parsingDone" << endl;
+//           kdDebug(24000) << "Calling cleanGroups from SAParser::parsingDone" << endl;
 #endif
           emit cleanGroups();
         }
@@ -825,6 +830,7 @@ Node *SAParser::parsingDone()
   {
       if (m_useNext && s_currentNode)
       {
+//           kdDebug(24000) << "s_currentNode: " << s_currentNode << endl;
         Node *n = s_currentNode;
         n->next = s_next;
         if (s_next)
