@@ -61,6 +61,7 @@
 #include "teammembersdlg.h"
 #include "uploadprofilespage.h"
 #include "viewmanager.h"
+#include "qpevents.h"
 
 extern QString simpleMemberStr;
 extern QString taskLeaderStr;
@@ -1255,7 +1256,20 @@ bool Project::queryClose()
           canExit = true;
     }
     if (canExit)
+    {
       emit eventHappened("after_project_close", d->baseURL.url(), QString::null);
+  // empty dom tree
+      d->dom.clear();
+      d->m_sessionDom.clear();
+      d->m_events->clear();
+      d->init();
+      newProjectLoaded(d->projectName, d->baseURL, d->templateURL);
+      reloadTree( &(d->m_projectFiles), true, QStringList());
+      d->adjustActions();
+      d->m_projectRecent->setCurrentItem(-1);
+      newStatus();
+//      kapp->processEvents(QEventLoop::ExcludeUserInput | QEventLoop::ExcludeSocketNotifiers);
+    }
   }
   return canExit;
 }
