@@ -19,13 +19,16 @@
 #define PROJECT_H
 
 #include <qobject.h>
-#include <ktexteditor/markinterface.h>
 
 #include "projecturl.h"
 
 class QDom;
 class ProjectPrivate;
 class ProjectList;
+namespace KTextEditor{
+  class MarkInterface;
+  class ViewCursorInterface;
+}
 struct EventAction;
 typedef  QMap<QString, QValueList<EventAction> > EventActions;
 
@@ -39,6 +42,7 @@ class KMainWindow;
 struct TeamMember {
   QString name;
   QString email;
+  QString nickName;
   QString task;
 };
 
@@ -69,8 +73,10 @@ public:
   ~Project();
 
   bool hasProject();
+  QString projectName();
 
   QStringList fileNameList();
+  KURL::List files();
 
   void insertFile( const KURL& nameURL, bool repaint );
   void readConfig(KConfig *);
@@ -99,12 +105,26 @@ public:
   QString password(const QString &entry);
   bool passwordSaved(const QString &entry);
   QDomDocument *dom();
+  QDomDocument *sessionDom();
   QString debuggerClient();
+  bool debuggerPersistentBreakpoints();
+  bool debuggerPersistentWatches();
   bool keepPasswd;
   QString email();
   KURL templateURL();
   KURL toolbarURL();
   EventActions* events();
+  /**
+   * Get the nickname of the current user (you)
+   * @return the nickname
+   */
+  QString yourself();
+  /**
+   * Get the roles of the current user in the form "role:task".
+   * Examples: "team leader", "project leader:subprojectname", "task leader:taskname". 
+   * @return the roles (in lowercase)
+   */
+  QStringList yourRoles();
   TeamMember teamLeader();
   TeamMember subprojectLeader(const QString &name);
   TeamMember taskLeader(const QString &name);
@@ -129,13 +149,15 @@ public:
   void saveBookmarks(const KURL &url, KTextEditor::MarkInterface *markIf);
   /** Loads the bookmarks for the url from the project file and sets them in the view*/
   void loadBookmarks(const KURL &url, KTextEditor::MarkInterface *markIf);
+  void saveCursorPosition(const KURL &url, KTextEditor::ViewCursorInterface *viewCursorIf);
+  void loadCursorPosition(const KURL &url, KTextEditor::ViewCursorInterface *viewCursorIf);
 
 public slots:
 
   void slotOpenProject(const KURL&);
   void slotOptions();
   void slotUpload();
-  void slotUploadURL(const KURL &urlToUpload, bool quickUpload);
+  void slotUploadURL(const KURL &urlToUpload, const QString &profileName, bool quickUpload, bool markOnly);
 
   void slotAddDirectory(const KURL& dirURL, bool showDlg = true);
   void slotInsertFile(const KURL& url);
