@@ -112,7 +112,7 @@ KURL::List ProjectNewLocal::projectFiles()
 {
   KURL::List list;
 
-  if (!QExtFileInfo::exists(baseURL, this) ||
+  if (!QExtFileInfo::exists(baseURL, false, this) ||
       !baseURL.path().endsWith("/")  ||
       !checkInsert->isChecked() ) return list;
 
@@ -205,7 +205,7 @@ void ProjectNewLocal::slotAddFiles()
         connect(dlg, SIGNAL(addFilesToProject(const KURL::List&)),
                      SLOT  (slotInsertFilesAfterCopying(const KURL::List&)));
         connect(dlg, SIGNAL(deleteDialog(CopyTo *)),
-                     SLOT  (slotDeleteCopyToDlg(CopyTo *)));
+                     SLOT  (slotDeleteCopyToDialog(CopyTo *)));
         list = dlg->copy( list, destination );
         return;
       } else
@@ -264,9 +264,9 @@ void ProjectNewLocal::slotAddFolder()
       {
         CopyTo *dlg = new CopyTo( baseURL);
         connect(dlg, SIGNAL(addFilesToProject(const KURL::List&)),
-                     SLOT  (slotInsertFilesAfterCopying(const KURL::List&)));
+                     SLOT  (slotInsertFolderAfterCopying(const KURL::List&)));
         connect(dlg, SIGNAL(deleteDialog(CopyTo *)),
-                     SLOT  (slotDeleteCopyToDlg(CopyTo *)));
+                     SLOT  (slotDeleteCopyToDialog(CopyTo *)));
         dirURL = dlg->copy(dirURL, destination);
         return;
       } else
@@ -285,7 +285,7 @@ void ProjectNewLocal::slotDeleteCopyToDialog(CopyTo* dlg)
   delete dlg;
 }
 
-void ProjectNewLocal::slotInsertFilesAfterCopying(const KURL::List& a_urlList)
+void ProjectNewLocal::slotInsertFolderAfterCopying(const KURL::List& a_urlList)
 {
   KURL::List::ConstIterator it;
   KURL dirURL;
@@ -296,13 +296,20 @@ void ProjectNewLocal::slotInsertFilesAfterCopying(const KURL::List& a_urlList)
     KURL::List files = QExtFileInfo::allFilesRelative(dirURL, "*", this);
     progressBar->setTotalSteps(files.count() - 1);
     progressBar->setTextEnabled(true);
+    KURL u;
     for (uint i = 0; i < files.count(); i++)
     {
-      if ( !fileList.contains(files[i]))
+      u = files[i];
+      if ( !fileList.contains(u) && u.path() != "." && u.path() != ".." )
       {
-        fileList.append(files[i]);
-        QListViewItem *it = listView->addItem(files[i], KFileItem(KFileItem::Unknown, KFileItem::Unknown, KURL()));
-        if (it)  it->setSelected(true);
+        fileList.append(u);
+        listView->addItem(u, KFileItem(KFileItem::Unknown, KFileItem::Unknown, KURL()));
+        QListViewItem *it = listView->itemByUrl(u);
+        if (it)
+        {
+          it->setSelected(true);
+          listView->slotSelectFile(it);
+        }
         progressBar->setValue(i);
       }
     }
@@ -313,6 +320,32 @@ void ProjectNewLocal::slotInsertFilesAfterCopying(const KURL::List& a_urlList)
   }
 }
 
+void ProjectNewLocal::slotInsertFilesAfterCopying(const KURL::List& a_urlList)
+{
+  KURL::List::ConstIterator it;
+  KURL u;
+  progressBar->setTotalSteps(a_urlList.count() - 1);
+  progressBar->setTextEnabled(true);
+  for (it = a_urlList.begin(); it != a_urlList.end(); ++it)
+  {
+    u = QExtFileInfo::toRelative(*it, baseURL);
+    if ( !fileList.contains(u))
+    {
+      fileList.append(u);
+      QListViewItem *it = listView->addItem(u, KFileItem(KFileItem::Unknown, KFileItem::Unknown, KURL()));
+      if (it)
+      {
+         it->setSelected(true);
+         listView->slotSelectFile(it);
+      }
+      progressBar->advance(1);
+    }
+  }
+  progressBar->setTotalSteps(1);
+  progressBar->setValue(0);
+  progressBar->setTextEnabled(false);
+}
+
 /** No descriptions */
 void ProjectNewLocal::slotClearList()
 {
