@@ -94,7 +94,6 @@ void ProjectPrivate::initActions(KActionCollection *ac)
                             ac, "project_open_recent");
   m_projectRecent->setText(i18n("Open Recent Project"));
   m_projectRecent->setIcon("project_open");
-  m_projectRecent->setMaxItems(32);
   m_projectRecent->setToolTip(i18n("Open/Open recent project"));
   connect(m_projectRecent, SIGNAL(activated()), this, SLOT(slotOpenProject()));
 
@@ -259,7 +258,7 @@ void ProjectPrivate::openCurrentView()
         if (el2.nodeName() == "viewitem")
         {
           urlsInView.append(url);
-          if (! ViewManager::ref()->isOpened(url))
+          if (!ViewManager::ref()->isOpened(url) && QExtFileInfo::exists(url, true, m_mainWindow))
             urlsToOpen.append(url);
         } else {
           if (el2.nodeName() == "viewtoolbar")
@@ -416,6 +415,12 @@ void ProjectPrivate::loadProjectXML()
     sessionNode.toElement().setAttribute("previewPrefix", previewPrefix.url());
     sessionNode.toElement().setAttribute("usePersistentBookmarks", m_persistentBookmarks ? "1" : "0");
   }
+  no = sessionNode.namedItem("itemcursorpositions");
+  if (no.isNull())
+  {
+    el = m_sessionDom.createElement("itemcursorpositions");
+    sessionNode.appendChild(el);
+  } 
   m_eventsEnabled = projectNode.toElement().attribute("enableEvents", "true") == "true";
   m_defaultEncoding = projectNode.toElement().attribute("encoding");
   if (m_defaultEncoding.isEmpty())
@@ -707,6 +712,14 @@ void ProjectPrivate::slotAcceptCreateProject()
 
   KURL oldBaseURL = baseURL;
   baseURL = KURL::fromPathOrURL(basePath);
+  if (baseURL.isLocalFile())
+  {
+    QString path = QDir(baseURL.path()).canonicalPath();
+    if (baseURL.path().endsWith("/"))
+      path.append("/");
+    if (!path.isEmpty())
+      baseURL.setPath(path);
+  }  
   /*
     it is important to set the fields only if there is some input
     otherwise you set them to an empty string and the treeview will
@@ -776,7 +789,7 @@ void ProjectPrivate::slotAcceptCreateProject()
 
       for ( KURL::List::Iterator it = list.begin(); it != list.end(); ++it )
       {
-        url = QExtFileInfo::toRelative(*it, baseURL );
+        url = *it;//QExtFileInfo::toRelative(*it, baseURL );
         el = dom.createElement("item");
         el.setAttribute("url",QuantaCommon::qUrl(url));
         dom.firstChild().firstChild().appendChild( el );
@@ -834,10 +847,6 @@ void ProjectPrivate::slotAcceptCreateProject()
     url = QExtFileInfo::toRelative(toolbarURL, baseURL);
     el.firstChild().setNodeValue(QuantaCommon::qUrl(url));
 
-    parent->newProjectLoaded(projectName, baseURL, templateURL);
-    m_projectFiles.readFromXML(dom, baseURL, templateURL, excludeRx);
-    parent->reloadTree( &(m_projectFiles), true, QStringList() );
-    saveProject();
 #if KDE_IS_VERSION(3,4,89)
     m_projectRecent->addURL(projectURL, projectName);
 #else
@@ -846,6 +855,11 @@ void ProjectPrivate::slotAcceptCreateProject()
     m_projectRecent->setCurrentItem(0);
     // remember the project in config
     writeConfig();
+
+//workaround to load the newly created project items in the treeview
+    KURL u = projectURL;
+    slotCloseProject();
+    loadProject(u);
   }
 }
 if (errorOccured)
@@ -1329,21 +1343,21 @@ void ProjectPrivate::loadProjectFromTemp(const KURL &url, const QString &tempFil
 }
 
 /** load project from file: url */
-void ProjectPrivate::loadProject(const KURL &url)
+bool ProjectPrivate::loadProject(const KURL &url)
 {
   if (projectURL == url)
-    return;
+    return true;
   if (!url.isValid())
   {
     parent->hideSplash();
     KMessageBox::sorry(m_mainWindow, i18n("<qt>Malformed URL: <b>%1</b></qt>").arg(url.prettyURL()));
-    return;
+    return false;
   }
   if ( projectAlreadyOpen(url.url()) )
   {
     parent->hideSplash();
     if (KMessageBox::warningContinueCancel(m_mainWindow, i18n("<qt>The project<br><b>%1</b><br> seems to be used by another Quanta instance.<br>You may end up with data loss if you open the same project in two instances, modify and save them in both.<br><br>Do you want to proceed with open?</qt>").arg(url.prettyURL()), QString::null, KStdGuiItem::open()) == KMessageBox::Cancel)
-      return;
+      return false;
   }
   QString projectTmpFile;
   QString sessionTmpFile;  
@@ -1402,7 +1416,9 @@ void ProjectPrivate::loadProject(const KURL &url)
   {
     parent->hideSplash();
     KMessageBox::error(m_mainWindow, i18n("<qt>Cannot access the project file <b>%1</b>.</qt>").arg(url.prettyURL(0, KURL::StripFileProtocol)));
+    return false;
   }
+  return true;
 }
 
 
@@ -1431,7 +1447,7 @@ void ProjectPrivate::slotAddFiles()
         CopyTo *dlg = new CopyTo( baseURL);
         connect(dlg, SIGNAL(deleteDialog(CopyTo*)),
                     SLOT  (slotDeleteCopytoDlg(CopyTo*)));
-        connect(dlg, SIGNAL(addFilesToProject(const KURL::List&)),
+        connect(dlg, SIGNAL(addFilesToProject(const KURL::List&)), parent,
                     SLOT  (slotInsertFilesAfterCopying(const KURL::List&)));
         list = dlg->copy( list, destination );
         return;
@@ -1441,17 +1457,17 @@ void ProjectPrivate::slotAddFiles()
       }
     }
 
-  insertFiles( list );
-  //Take care also of the selected dirs
-  KURL dirURL;
-  for (uint i = 0; i < list.count(); i++)
-  {
-    dirURL = list[i];
-    if (dirURL.path().endsWith("/"))
+    insertFiles( list );
+    //Take care also of the selected dirs
+    KURL dirURL;
+    for (uint i = 0; i < list.count(); i++)
     {
-      insertFiles( dirURL, "*" );
+      dirURL = list[i];
+      if (dirURL.path().endsWith("/"))
+      {
+        insertFiles( dirURL, "*" );
+      }
     }
-  }
 
     parent->reloadTree( &(m_projectFiles), false, QStringList());
   }
@@ -1467,10 +1483,10 @@ void ProjectPrivate::slotDeleteCopytoDlg(CopyTo *dlg)
 
 void ProjectPrivate::slotAddDirectory()
 {
-KURL url = KURL();
-url = KFileDialog::getExistingURL(baseURL.prettyURL(), m_mainWindow,
-                i18n("Insert Folder in Project"));
-parent->slotAddDirectory(url);
+  KURL url = KURL();
+  url = KFileDialog::getExistingURL(baseURL.prettyURL(), m_mainWindow,
+                  i18n("Insert Folder in Project"));
+  parent->slotAddDirectory(url);
 }
 
 
@@ -1484,7 +1500,7 @@ void ProjectPrivate::slotDebuggerOptions()
     KService::Ptr service = *iterDbg;
     if(m_debuggerClientEdit == service->name())
     {
-      DebuggerClient *dbg = dbg;
+      DebuggerClient *dbg = 0L;
       int errCode = 0;
 //Workaround for dynamic_cast not working correctly on SUSE 10, gcc 4.0.2
 //The correct way should be a simple:
@@ -1532,7 +1548,9 @@ void ProjectPrivate::writeConfig()
   config->reparseConfiguration();
   config->setGroup("Projects");
   // remember the last project in config
-  config->writePathEntry("Last Project", projectURL.url());
+  KURL url = projectURL.url();
+  url.setPass("");
+  config->writePathEntry("Last Project", url.url());
   // add project to list
   if (!projectURL.isEmpty())
   {
