@@ -194,6 +194,7 @@ Document::Document(KTextEditor::Document *doc,
   dtdName = Project::ref()->defaultDTD();
   reparseEnabled = true;
   repaintEnabled = true;
+  delayedTextChangedEnabled = true;
   docUndoRedo = new undoRedo(this);
 
   //each document remember wheter it has a entry in quantarc
@@ -549,6 +550,7 @@ void Document::insertText(const QString &a_text, bool adjustCursor, bool reparse
       typingInProgress = false;
       StructTreeView::ref()->slotReparse(this, baseNode , qConfig.expandLevel);
     }
+    quantaApp->updateTreeViews();
   }
 }
 
@@ -2264,11 +2266,13 @@ bool Document::evenQuotes(const QString &text)
 void Document::slotTextChanged()
 {
   changed = true;
-  if (reparseEnabled)
+  parser->setSAParserEnabled(false); //disable special area parsing if the text was changed.
+  if (reparseEnabled && delayedTextChangedEnabled)
   {
     kdDebug(24000) << "Delayed text changed called." << endl;
     //delay the handling, otherwise we may get wrong values for (line,column)
     QTimer::singleShot(0, this, SLOT(slotDelayedTextChanged()));
+    delayedTextChangedEnabled = false;  
   }
 }
 
@@ -2276,13 +2280,14 @@ void Document::slotDelayedTextChanged(bool forced)
 {
    if (!forced && typingInProgress)
    {
-    // kdDebug(24000) << "Reparsing delayed!" << endl;
+     kdDebug(24000) << "Reparsing delayed!" << endl;
      parser->setParsingNeeded(true);
      QTimer::singleShot(1000, this, SLOT(slotDelayedTextChanged()));
      reparseEnabled = false;
+     delayedTextChangedEnabled = false;	
      return;
    }
-
+	
     uint line, column;
     QString oldNodeName = "";
     Node *node;
@@ -2311,7 +2316,7 @@ void Document::slotDelayedTextChanged(bool forced)
         }
       }
     }
-
+    parser->setSAParserEnabled(true); //enable special area parsing, it was disabled in slotTextChanged()
     baseNode = parser->rebuild(this);
     if (qConfig.updateClosingTags && currentNode)
     {
@@ -2329,6 +2334,7 @@ void Document::slotDelayedTextChanged(bool forced)
           previousNode->tag->beginPos(bl2, bc2);
           delete currentNode;
           currentNode = previousNode;
+          previousNode = 0L;
         } else
         {
           delete previousNode;
@@ -2396,9 +2402,10 @@ void Document::slotDelayedTextChanged(bool forced)
             else
               node = node->previousSibling();
           }
-          delete currentNode;
         }
       }
+      delete currentNode;
+      delete previousNode;
     }
 
     quantaApp->slotNewLineColumn();
@@ -2408,6 +2415,7 @@ void Document::slotDelayedTextChanged(bool forced)
       StructTreeView::ref()->slotReparse(this, baseNode , qConfig.expandLevel);
     }
     reparseEnabled = true;
+   delayedTextChangedEnabled = true;	
 }
 
 /** Returns list of values for attribute */
