@@ -26,8 +26,11 @@
 
 // include files for KDE
 #include <kapplication.h>
+#include <kcombobox.h>
 #include <kconfig.h>
+#include <kdialogbase.h>
 #include <kurl.h>
+#include <kurlrequester.h>
 #include <kglobal.h>
 #include <kmessagebox.h>
 #include <klocale.h>
@@ -41,6 +44,7 @@
 #include "dtdparser.h"
 #include "document.h"
 #include "viewmanager.h"
+#include "loadentitydlgs.h"
 
 #include "dtds.h"
 
@@ -62,23 +66,47 @@ DTDs::DTDs(QObject *parent)
   m_dict->setAutoDelete(true);
   m_doc = new QDomDocument();
 
+  QString localKDEdir = KGlobal::instance()->dirs()->localkdedir();
   QStringList tagsResourceDirs = KGlobal::instance()->dirs()->findDirs("appdata", "dtep");
   QStringList tagsDirs;
-  for ( QStringList::Iterator it = tagsResourceDirs.begin(); it != tagsResourceDirs.end(); ++it )
+  QStringList::ConstIterator end = tagsResourceDirs.constEnd();
+  for ( QStringList::ConstIterator it = tagsResourceDirs.constBegin(); it != end; ++it )
   {
-    QDir dir(*it);
-    dir.setFilter(QDir::Dirs);
-    QStringList subDirs = dir.entryList();
-    for ( QStringList::Iterator subit = subDirs.begin(); subit != subDirs.end(); ++subit )
+    if ((*it).startsWith(localKDEdir))
     {
-//      kdDebug(24000) << "dtds::dtds add:" << *it + *subit+"/" << endl;
-      if ((*subit != ".") && (*subit != ".."))
-         tagsDirs += *it + *subit+"/";
+      QDir dir(*it);
+      dir.setFilter(QDir::Dirs);
+      QStringList subDirs = dir.entryList();
+      QStringList::ConstIterator subitEnd = subDirs.constEnd();
+      for ( QStringList::ConstIterator subit = subDirs.constBegin(); subit != subitEnd; ++subit )
+      {
+//         kdDebug(24000) << "dtds::dtds add:" << *it + *subit+"/" << endl;
+        if ((*subit != ".") && (*subit != ".."))
+          tagsDirs += *it + *subit + "/";
+      }
+    }
+  }
+  for ( QStringList::ConstIterator it = tagsResourceDirs.constBegin(); it != end; ++it )
+  {
+    if (!(*it).startsWith(localKDEdir))
+    {
+      QDir dir(*it);
+      dir.setFilter(QDir::Dirs);
+      QStringList subDirs = dir.entryList();
+      QStringList::ConstIterator subitEnd = subDirs.constEnd();
+      for ( QStringList::ConstIterator subit = subDirs.constBegin(); subit != subitEnd; ++subit )
+      {
+//         kdDebug(24000) << "dtds::dtds add2:" << *it + *subit+"/" << endl;
+        if ((*subit != ".") && (*subit != ".."))
+          tagsDirs += *it + *subit + "/";
+      }
     }
   }
 //  kdDebug(24000) << tagsDirs.count() << " folders found." << endl;
-  for ( QStringList::Iterator it = tagsDirs.begin(); it != tagsDirs.end(); ++it )
+  QStringList::ConstIterator tagsDirsEnd = tagsDirs.constEnd();
+  for ( QStringList::ConstIterator it = tagsDirs.constBegin(); it != tagsDirsEnd; ++it )
   {
+//     kdDebug(24000) << "read:" << *it  << endl;
     readTagDir(*it, false);  // read all tags, but only short form
   }
 //  kdDebug(24000) << "dtds::dtds constructed" << endl;
@@ -221,13 +249,14 @@ bool DTDs::readTagDir2(DTDStruct *dtd)
     readTagFile(dirName + "common.tag", dtd, 0L);
   //bool idleTimerStatus = quantaApp->slotEnableIdleTimer(false);
   emit enableIdleTimer(false);
-  KURL::List files = QExtFileInfo::allFilesRelative(dirURL, "*.tag");
+  KURL::List files = QExtFileInfo::allFilesRelative(dirURL, "*.tag", 0L);
   //quantaApp->slotEnableIdleTimer(idleTimerStatus);
   emit enableIdleTimer(true);
   QString tmpStr;
-  for ( KURL::List::Iterator it_f = files.begin(); it_f != files.end(); ++it_f )
+  KURL::List::ConstIterator end_f = files.constEnd();
+  for ( KURL::List::ConstIterator it_f = files.constBegin(); it_f != end_f; ++it_f )
   {
-    tmpStr = (*it_f).fileName();
+    tmpStr = (*it_f).path(-1);
     if (!tmpStr.isEmpty())
     {
       tmpStr.prepend(dirName);
@@ -447,6 +476,7 @@ bool DTDs::readTagDir2(DTDStruct *dtd)
       dtd->tagAutoCompleteAfter = '\1';
   else
       dtd->tagAutoCompleteAfter = tmpStr.at(0);
+  dtd->requestSpaceBeforeTagAutoCompletion = dtdConfig->readBoolEntry("RequestSpaceBeforeTagAutoCompletion", false);
   dtd->attrAutoCompleteAfter = dtdConfig->readEntry("AttributeAutoCompleteAfter","(").stripWhiteSpace().at(0);
   dtd->attributeSeparator = dtdConfig->readEntry("AttributeSeparator").stripWhiteSpace().at(0);
   if (dtd->attributeSeparator.isNull())
@@ -676,10 +706,10 @@ uint DTDs::readTagFile(const QString& fileName, DTDStruct* parentDTD, QTagList *
     {
       if (parentDTD->caseSensitive)
       {
-        tagList->insert(tag->name(), tag);  //append the tag to the list for this DTD
+        tagList->replace(tag->name(), tag);  //append the tag to the list for this DTD
       } else
       {
-        tagList->insert(tag->name().upper(), tag);
+        tagList->replace(tag->name().upper(), tag);
       }
     }
  }
@@ -701,14 +731,17 @@ void DTDs::setAttributes(QDomNode *dom, QTag* tag, bool &common)
  tmpStr = el.attribute("common");
  if ((tmpStr != "1" && tmpStr != "yes")) //in case of common tags, we are not interested in these options
  {
-    QDictIterator<AttributeList> it(*(tag->parentDTD->commonAttrs));
-    for( ; it.current(); ++it )
+    if (tag->parentDTD->commonAttrs)
     {
-      QString lookForAttr = "has" + QString(it.currentKey()).stripWhiteSpace();
-      tmpStr = el.attribute(lookForAttr);
-      if (tmpStr == "1" || tmpStr == "yes")
+      QDictIterator<AttributeList> it(*(tag->parentDTD->commonAttrs));
+      for( ; it.current(); ++it )
       {
-        tag->commonGroups += QString(it.currentKey()).stripWhiteSpace();
+        QString lookForAttr = "has" + QString(it.currentKey()).stripWhiteSpace();
+        tmpStr = el.attribute(lookForAttr);
+        if (tmpStr == "1" || tmpStr == "yes")
+        {
+          tag->commonGroups += QString(it.currentKey()).stripWhiteSpace();
+        }
       }
     }
 
@@ -724,6 +757,9 @@ void DTDs::setAttributes(QDomNode *dom, QTag* tag, bool &common)
       tag->setOptional(true);
     }
 
+    tmpStr = el.attribute("scope");
+    tag->setScope(tmpStr);
+
     tag->type = el.attribute("type", "xmltag");
     tag->returnType = el.attribute("returnType", "");
     tag->className = el.attribute("class", "");
@@ -846,7 +882,7 @@ void DTDs::setAttributes(QDomNode *dom, QTag* tag, bool &common)
 
 void DTDs::slotLoadDTD()
 {
-  KURL url = KFileDialog::getOpenURL("", "*.dtd", 0L);
+  KURL url = KFileDialog::getOpenURL("", i18n("*.dtd|DTD Definitions"), 0L);
   if (!url.isEmpty())
   {
     DTDParser dtdParser(url, KGlobal::dirs()->saveLocation("data") + resourceDir + "dtep");
@@ -859,7 +895,7 @@ void DTDs::slotLoadDTD()
       QString nickName = dtdcfg.readEntry("NickName", dtdName);
       DTDStruct * dtd = m_dict->find(dtdName) ;
       if (dtd &&
-          KMessageBox::warningYesNo(0L, i18n("<qt>Do you want to replace the existing <b>%1</b> DTD?</qt>").arg(nickName)) == KMessageBox::No)
+          KMessageBox::warningYesNo(0L, i18n("<qt>Do you want to replace the existing <b>%1</b> DTD?</qt>").arg(nickName), QString::null, i18n("Replace"), i18n("Do Not Replace")) == KMessageBox::No)
       {
         return;
       }
@@ -869,7 +905,7 @@ void DTDs::slotLoadDTD()
           QString family = dtdcfg.readEntry("Family", "1");
           Document *w = ViewManager::ref()->activeDocument();
           if (family == "1" && w &&
-              KMessageBox::questionYesNo(0L, i18n("<qt>Use the newly loaded <b>%1</b> DTD for the current document?</qt>").arg(nickName), i18n("Change DTD")) == KMessageBox::Yes)
+              KMessageBox::questionYesNo(0L, i18n("<qt>Use the newly loaded <b>%1</b> DTD for the current document?</qt>").arg(nickName), i18n("Change DTD"), i18n("Use"), i18n("Do Not Use")) == KMessageBox::Yes)
           {
             w->setDTDIdentifier(dtdName);
             emit loadToolbarForDTD(w->getDTDIdentifier());
@@ -891,7 +927,7 @@ void DTDs::slotLoadDTEP(const QString &_dirName, bool askForAutoload)
   QString nickName = dtdcfg.readEntry("NickName", dtdName);
   DTDStruct * dtd = m_dict->find(dtdName) ;
   if ( dtd &&
-      KMessageBox::warningYesNo(0L, i18n("<qt>Do you want to replace the existing <b>%1</b> DTD?</qt>").arg(nickName)) == KMessageBox::No)
+      KMessageBox::warningYesNo(0L, i18n("<qt>Do you want to replace the existing <b>%1</b> DTD?</qt>").arg(nickName), QString::null, i18n("Replace"), i18n("Do Not Replace")) == KMessageBox::No)
   {
     return;
   }
@@ -902,7 +938,7 @@ void DTDs::slotLoadDTEP(const QString &_dirName, bool askForAutoload)
   } else
   {
     QString family = dtdcfg.readEntry("Family", "1");
-    if (askForAutoload && KMessageBox::questionYesNo(0L, i18n("<qt>Autoload the <b>%1</b> DTD in the feature?</qt>").arg(nickName)) == KMessageBox::Yes)
+    if (askForAutoload && KMessageBox::questionYesNo(0L, i18n("<qt>Autoload the <b>%1</b> DTD in the future?</qt>").arg(nickName), QString::null, i18n("Load"), i18n("Do Not Load")) == KMessageBox::Yes)
     {
       KURL src;
       src.setPath(dirName);
@@ -913,7 +949,7 @@ void DTDs::slotLoadDTEP(const QString &_dirName, bool askForAutoload)
     }
     Document *w = ViewManager::ref()->activeDocument();
     if (family == "1" && w &&
-        KMessageBox::questionYesNo(0L, i18n("<qt>Use the newly loaded <b>%1</b> DTD for the current document?</qt>").arg(nickName), i18n("Change DTD")) == KMessageBox::Yes)
+        KMessageBox::questionYesNo(0L, i18n("<qt>Use the newly loaded <b>%1</b> DTD for the current document?</qt>").arg(nickName), i18n("Change DTD"), i18n("Use"), i18n("Do Not Use")) == KMessageBox::Yes)
     {
       w->setDTDIdentifier(dtdName);
       emit loadToolbarForDTD(w->getDTDIdentifier());
@@ -922,6 +958,31 @@ void DTDs::slotLoadDTEP(const QString &_dirName, bool askForAutoload)
   }
 }
 
+void DTDs::slotLoadEntities()
+{
+  KDialogBase dlg(0L, "loadentities", true, i18n("Load DTD Entities Into DTEP"), KDialogBase::Ok | KDialogBase::Cancel);
+  LoadEntityDlgS entitiesWidget(&dlg);
+  QStringList lst(DTDs::ref()->nickNameList(true));
+  entitiesWidget.targetDTEPCombo->insertStringList(lst);
+  Document *w = ViewManager::ref()->activeDocument();
+  if (w)
+  {
+    QString nickName = DTDs::ref()->getDTDNickNameFromName(w->getDTDIdentifier());
+    entitiesWidget.targetDTEPCombo->setCurrentItem(lst.findIndex(nickName));
+  }
+  dlg.setMainWidget(&entitiesWidget);
+  if (dlg.exec())
+  {
+    DTDStruct * dtd = m_dict->find(getDTDNameFromNickName(entitiesWidget.targetDTEPCombo->currentText()));
+    DTDParser dtdParser(KURL::fromPathOrURL(entitiesWidget.sourceDTDRequester->url()), KGlobal::dirs()->saveLocation("data") + resourceDir + "dtep");
+    QString dtdDir = QFileInfo(dtd->fileName).dirPath();
+    if (dtdParser.parse(dtdDir, true))
+    {
+      readTagFile(dtdDir + "/entities.tag", dtd, dtd->tagsList);
+    }
+  }
+}
+
 
 /** Returns the DTD name (identifier) corresponding to the DTD's nickname */
 QString DTDs::getDTDNameFromNickName(const QString& nickName)
