@@ -400,8 +400,8 @@ void QuantaInit::initProject()
           m_project, SLOT(slotInsertFile(const KURL&)));
   connect(pTab, SIGNAL(removeFromProject(const KURL&)),
           m_project, SLOT(slotRemove(const KURL&)));
-  connect(pTab, SIGNAL(uploadSingleURL(const KURL&, bool)),
-          m_project, SLOT(slotUploadURL(const KURL&, bool)));
+  connect(pTab, SIGNAL(uploadSingleURL(const KURL&, const QString&, bool, bool)),
+          m_project, SLOT(slotUploadURL(const KURL&, const QString&, bool, bool)));
   connect(pTab, SIGNAL(rescanProjectDir()), m_project, SLOT(slotRescanPrjDir()));
   connect(pTab, SIGNAL(showProjectOptions()), m_project, SLOT(slotOptions()));
   connect(pTab, SIGNAL(uploadProject()), m_project, SLOT(slotUpload()));
@@ -592,6 +592,8 @@ void QuantaInit::readOptions()
   m_quanta->fileRecent ->loadEntries(m_config);
   qConfig.showHiddenFiles = m_config->readBoolEntry("Show Hidden Files", true);
   qConfig.saveTrees = m_config->readBoolEntry("Save Local Trees", true);
+  int maxRecentItems = m_config->readNumEntry("Recent Files Limit", 32);
+  m_quanta->fileRecent->setMaxItems(maxRecentItems);
 
   m_config->setGroup("Parser options");
   qConfig.showEmptyNodes = m_config->readBoolEntry("Show Empty Nodes", false);
@@ -668,7 +670,7 @@ void QuantaInit::openLastFiles()
   Document *w = ViewManager::ref()->activeDocument();
   if (w) //w==0 might happen on quick close on startup
   {
-    m_quanta->setCaption(w->url().prettyURL() );
+    m_quanta->setTitle(w->url().prettyURL(0, KURL::StripFileProtocol) );
 //    m_quanta->slotUpdateStatus(w);//FIXME:
   }
 }
@@ -730,7 +732,6 @@ void QuantaInit::initActions()
 
     m_quanta->fileRecent =  KStdAction::openRecent(m_quanta, SLOT(slotFileOpenRecent(const KURL&)),
                                          ac, "file_open_recent");
-    m_quanta->fileRecent->setMaxItems(32);
     m_quanta->fileRecent->setToolTip(i18n("Open / Open Recent"));
     connect(m_quanta->fileRecent, SIGNAL(activated()), m_quanta, SLOT(slotFileOpen()));
 
@@ -888,6 +889,7 @@ void QuantaInit::initActions()
                         m_quanta, SLOT( slotOptionsConfigureActions() ),
                         ac, "configure_actions" );
 
+    KStdAction::showMenubar(m_quanta, SLOT(slotShowMenuBar()), ac, "options_show_menubar");
     KStdAction::keyBindings(m_quanta, SLOT( slotOptionsConfigureKeys() ), ac, "configure_shortcuts");
     KStdAction::configureToolbars( m_quanta, SLOT( slotOptionsConfigureToolbars() ), ac, "options_configure_toolbars");
     KStdAction::preferences(m_quanta, SLOT( slotOptions() ), ac, "general_options");
@@ -915,9 +917,7 @@ void QuantaInit::initActions()
     m_quanta->showDTDToolbar=new KToggleAction(i18n("Show DTD Toolbar"), 0, ac, "view_dtd_toolbar");
 
     connect(m_quanta->showDTDToolbar, SIGNAL(toggled(bool)), m_quanta, SLOT(slotToggleDTDToolbar(bool)));
-#if KDE_IS_VERSION(3,2,90)
     m_quanta->showDTDToolbar->setCheckedState(i18n("Hide DTD Toolbar"));
-#endif
 
     new KAction(i18n("Complete Text"), CTRL+Key_Space,
                 m_quanta, SLOT(slotShowCompletion()), ac,"show_completion");
@@ -949,7 +949,8 @@ void QuantaInit::initActions()
         while( !n.isNull() ) {
           QDomElement e = n.toElement(); // try to convert the node to an element.
           if( !e.isNull() ) { // the node was really an element.
-              new TagAction(&e, m_quanta);
+              bool toggable = (e.attribute("toggable", "") == "true");
+              new TagAction(&e, m_quanta, toggable);
           }
           n = n.nextSibling();
         }
@@ -975,7 +976,8 @@ void QuantaInit::initActions()
             if( !e.isNull())
             { // the node was really an element.
                 delete ac->action(e.attribute("name"));
-                new TagAction(&e, m_quanta);
+                bool toggable = (e.attribute("toggable", "") == "true");
+                new TagAction(&e, m_quanta, toggable);
             }
             n = n.nextSibling();
           }
