@@ -153,6 +153,18 @@ void ViewManager::createNewDocument()
 bool ViewManager::removeView(QuantaView *view, bool force, bool createNew)
 {
     if (!view) return false;
+    int noOfViews = 0;
+    QValueList<Document*> list;
+    KMdiIterator<KMdiChildView*> *it = quantaApp->createIterator();
+    for (it->first(); !it->isDone(); it->next())
+    {
+      noOfViews++;
+      if (noOfViews > 1)
+        break;
+    }
+    delete it;
+    if (noOfViews == 1 && view->document()->isUntitled() && !view->document()->isModified() && createNew)
+      return true;
     bool mayRemove = view->mayRemove();
     if (mayRemove)
     {
@@ -206,7 +218,7 @@ void ViewManager::slotViewActivated(KMdiChildView *view)
    qView->activated();
 
 #ifdef DEBUG_PARSER
-  kdDebug(24000) << "Calling clearGroups from ViewManager::slotViewActivated" << endl;
+//   kdDebug(24000) << "Calling clearGroups from ViewManager::slotViewActivated" << endl;
 #endif
   parser->clearGroups();
   parser->setSAParserEnabled(true);
