@@ -171,11 +171,6 @@ BaseTreeBranch::BaseTreeBranch(KFileTreeView *parent, const KURL& url,
   setAutoUpdate(localFile);
   setChildRecurse(false);
 
-  // TODO drop this if support for KDE 3.2 is dropped
-#if KDE_VERSION < KDE_MAKE_VERSION(3,2,90)
-  connect(this, SIGNAL(refreshItems(const KFileItemList&)),
-          this, SLOT   (slotRefreshItems(const KFileItemList&)));
-#endif
 }
 
 bool BaseTreeBranch::matchesFilter(const KFileItem *item) const
@@ -205,28 +200,6 @@ KFileTreeViewItem* BaseTreeBranch::createTreeViewItem(KFileTreeViewItem *parent,
   return tvi;
 }
 
-// TODO drop this if support for KDE 3.2 is dropped
-void BaseTreeBranch::slotRefreshItems(const KFileItemList& list)
-{
-#if KDE_VERSION < KDE_MAKE_VERSION(3,2,90)
-  KFileItemListIterator it( list );
-  KFileItem *currItem;
-  KFileTreeViewItem *item = 0;
-
-  while ( (currItem = it.current()) != 0 )
-  {
-      item = findTVIByURL(currItem->url());
-      if (item) {
-          item->setPixmap(0, item->fileItem()->pixmap( KIcon::SizeSmall ));
-          item->setText( 0, item->fileItem()->text());
-      }
-      ++it;
-  }
-#else
-  Q_UNUSED(list);
-#endif
-}
-
 
 void BaseTreeBranch::addOpenFolder(QStringList* openFolder)
 {
@@ -1026,7 +999,7 @@ void BaseTreeView::doRename(KFileTreeViewItem* kftvi, const QString & newName)
   if ( oldURL != newURL )
   {
     bool proceed = true;
-    if (QExtFileInfo::exists(newURL, this))
+    if (QExtFileInfo::exists(newURL, false, this))
     {
       proceed = KMessageBox::warningContinueCancel(this, i18n("<qt>The file <b>%1</b> already exists.<br>Do you want to overwrite it?</qt>").arg(newURL.prettyURL(0, KURL::StripFileProtocol)),i18n("Overwrite"), i18n("Overwrite")) == KMessageBox::Continue;
     }
@@ -1204,7 +1177,7 @@ void BaseTreeView::slotCreateFile()
       url.setPath(url.path() + "/" + fileName);
     else
       url.setPath(url.directory() + "/" + fileName);
-    if (QExtFileInfo::exists(url, this))
+    if (QExtFileInfo::exists(url, false, this))
     {
       KMessageBox::error(this, i18n("<qt>Cannot create file, because a file named <b>%1</b> already exists.</qt>").arg(fileName), i18n("Error Creating File"));
       return;
