@@ -332,6 +332,7 @@ void ProjectTreeView::slotReloadTree( ProjectList *fileList, bool buildNewTree,
     if (btb && folderToOpen.count() > 0) {
       btb->folderToOpen = folderToOpen;
       btb->reopenFolder();
+      btb->updateOpenFolder();
     }
   } else
   {
@@ -397,7 +398,7 @@ void ProjectTreeView::slotCreateFile()
       url.setPath(url.path() + "/" + fileName);
     else
       url.setPath(url.directory() + "/" + fileName);
-    if (QExtFileInfo::exists(url, this))
+    if (QExtFileInfo::exists(url, false, this))
     {
       KMessageBox::error(this, i18n("<qt>Cannot create file, because a file named <b>%1</b> already exists.</qt>").arg(fileName), i18n("Error Creating File"));
       return;
@@ -439,7 +440,7 @@ void ProjectTreeView::slotUploadSingleURL()
   {
     KURL url = currentURL();
     if ( currentKFileTreeViewItem()->isDir() ) url.adjustPath(+1);
-    emit uploadSingleURL(url, false);
+    emit uploadSingleURL(url, "", false, false);
   }
 }
 
@@ -449,13 +450,15 @@ void ProjectTreeView::slotQuickUploadURL()
   {
     KURL url = currentURL();
     if ( currentKFileTreeViewItem()->isDir() ) url.adjustPath(+1);
-    emit uploadSingleURL(url, true);
+    emit uploadSingleURL(url, "", true, false);
   }
 }
 
 void ProjectTreeView::slotRescan()
 {
   emit rescanProjectDir();
+  if (!m_projectBaseURL.isLocalFile())
+    slotReload();
 }
 
 /** Bring up the project options dialog */
